==> tine20-allinone_2016.11.24.tar.bz2: Addressbook/js/Addressbook-lang-de-debug.js <==
/********************** tine translations of Addressbook**********************/ 
Locale.Gettext.prototype._msgs['./LC_MESSAGES/Addressbook'] = new Locale.Gettext.PO(({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2016-08-11 14:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: German (http://www.transifex.com/tine20/tine20/language/de/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: de\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Business Contact Data"
: "Geschäftliche Kontaktdaten"

, "Organisation / Unit"
: "Firma / Abteilung"

, "Business Address"
: "Geschäftliche Anschrift"

, "Email"
: "E-Mail"

, "Telephone Work"
: "Telefon (Büro)"

, "Telephone Cellphone"
: "Telefon (Mobil)"

, "Telephone Car"
: "Telefon (Auto)"

, "Telephone Fax"
: "Fax"

, "Telephone Page"
: "Pager"

, "URL"
: "URL"

, "Role"
: "Funktion"

, "Room"
: "Raum"

, "Assistant"
: "Assistent"

, "Assistant Telephone"
: "Telefon des Assistenten"

, "Private Contact Data"
: "Private Kontaktdaten"

, "Private Address"
: "Private Anschrift"

, "Email Home"
: "E-Mail  (Zuhause)"

, "Telephone Home"
: "Telefon  (Zuhause)"

, "Telephone Cellphone Private"
: "Telefon (Mobil)"

, "Telephone Fax Home"
: "Fax (Zuhause)"

, "URL Home"
: "URL (Zuhause)"

, "Other Data"
: "Andere Daten"

, "Birthday"
: "Geburtstag"

, "Job Title"
: "Berufs-Bezeichnung"

, "Dear Mister"
: "Sehr geehrter Herr"

, "Dear Miss"
: "Sehr geehrte Dame"

, "Dear"
: "Sehr geehrte Damen und Herren"

, "Mister"
: "Herr"

, "Misses"
: "Frau"

, "%s's personal addressbook"
: "%ss persönliches Adressbuch"

, "Lists"
: "Gruppen"

, "List Roles"
: "Gruppenrollen"

, "manage shared addressbooks"
: "Gemeinsame Adressbücher verwalten"

, "Create new shared addressbook folders"
: "Neue gemeinsame Adressbücher anlegen"

, "manage shared addressbook favorites"
: "Gemeinsame Adressbuch-Favoriten verwalten"

, "Create or update shared addressbook favorites"
: "Gemeinsame Adressbuch-Favoriten erstellen oder bearbeiten"

, "Manage lists in CoreData"
: "Verwalte Listen in den Stammdaten"

, "View, create, delete or update lists in CoreData application"
: ""

, "Manage list roles in CoreData"
: "Verwalte Listen Rollen in den Stammdaten"

, "View, create, delete or update list roles in CoreData application"
: ""

, "Search for system groups ..."
: "Suche nach Systemgruppen ..."

, "Search for groups ..."
: "Suche nach Gruppen ..."

, "CardDAV URL"
: "CardDAV URL"

, "Contact, Contacts"
: [
  "Kontakt"
 ,"Kontakte"

]
, "List Role, , n); gettext("
: [
  "Gruppenrolle"
 ,"Gruppenrollen"

]
, "Members"
: "Mitglieder"

, "Remove Member"
: "Mitglied entfernen"

, "Map"
: "Karte"

, "Personal Information"
: "Persönliche Informationen"

, "Salutation"
: "Anrede"

, "Title"
: "Titel"

, "First Name"
: "Vorname"

, "Middle Name"
: "zweiter Vorname"

, "Last Name"
: "Nachname"

, "Company"
: "Firma"

, "Unit"
: "Abteilung"

, "Suffix"
: "Namenszusatz"

, "Job Role"
: "Funktion"

, "Display Name"
: "Angezeigter Name"

, "Contact Information"
: "Kontakt-Informationen"

, "Phone"
: "Telefon"

, "Mobile"
: "Handy"

, "Fax"
: "Fax"

, "Phone (private)"
: "Telefon (privat)"

, "Mobile (private)"
: "Handy (privat)"

, "Fax (private)"
: "Fax (privat)"

, "E-Mail"
: "E-Mail"

, "E-Mail (private)"
: "E-Mail (privat)"

, "Web"
: "Internet"

, "Company Address"
: "Geschäftliche Anschrift"

, "Street"
: "Straße"

, "Street 2"
: "Straße 2"

, "Region"
: "Region"

, "Postal Code"
: "Postleitzahl"

, "City"
: "Ort"

, "Country"
: "Land"

, "Description"
: "Beschreibung"

, "Enter description"
: "Bitte geben Sie eine Beschreibung an"

, "Export as pdf"
: "Als PDF exportieren"

, "Parse address"
: "Adresse einlesen"

, "Paste address"
: "Adresse einfügen"

, "Please paste an address or a URI to a vcard that should be parsed:"
: "Bitte fügen Sie eine Adresse oder URI zu einer vcard ein, die eingelesen werden soll:"

, "Failed to parse address!"
: "Einlesen der Adresse fehlgeschlagen!"

, "The address could not be read."
: "Die Adresse konnte nicht gelesen werden."

, "End token mode"
: "Beende Merkmalsmodus"

, "New Contact"
: "Neuer Kontakt"

, "Addressbook, Addressbooks"
: [
  "Adressbuch"
 ,"Adressbücher"

]
, "ID"
: "ID"

, "Name"
: "Name"

, "Member of List"
: "Gruppenmitglied"

, "Street (Company Address)"
: "Straße (Geschäftliche Anschrift)"

, "Street 2 (Company Address)"
: "Straße 2 (Geschäftliche Anschrift)"

, "City (Company Address)"
: "Ort (Geschäftliche Anschrift)"

, "Region (Company Address)"
: "Region (Geschäftliche Anschrift)"

, "Postal Code (Company Address)"
: "Postleitzahl (Geschäftliche Anschrift)"

, "Country (Company Address)"
: "Land (Geschäftliche Anschrift)"

, "Longitude (Company Address)"
: "Längengrad (Firmenadresse )"

, "Latitude (Company Address)"
: "Breitengrad (Firmenadresse )"

, "Street (Private Address)"
: "Straße (Private Anschrift)"

, "Street 2 (Private Address)"
: "Straße 2 (Private Anschrift)"

, "City (Private Address)"
: "Ort (Private Anschrift)"

, "Region (Private Address)"
: "Region (Private Anschrift)"

, "Postal Code (Private Address)"
: "Postleitzahl (Private Anschrift)"

, "Country (Private Address)"
: "Land (Private Anschrift)"

, "Company Communication"
: "Firmenkommunikation"

, "Private Communication"
: "Privatkommunikation"

, "Web (private)"
: "Webseite (Privat)"

, "Contacts"
: "Kontakte"

, "Addressbooks"
: "Adressbücher"

, "User Account"
: "Benutzerkonto"

, "Quick Search"
: "Schnellsuche"

, "Type"
: "Typ"

, "Last Modified Time"
: "Zuletzt geändert"

, "Last Modified By"
: "Zuletzt geändert von"

, "Creation Time"
: "Erstelldatum"

, "Created By"
: "Angelegt von"

, "List, Lists"
: [
  "Gruppe"
 ,"Gruppen"

]
, "Quick search"
: "Schnellsuche"

, "Email Address, Email Addresses"
: [
  "E-mail Adresse"
 ,"E-mail Adressen"

]
, "Email Addresses"
: "E-mail Adressen"

, "Select list"
: "Gruppe auswählen"

, "Tags"
: "Tags"

, "List type"
: "Listen Typ"

, "Emails"
: "E-Mail"

, "System Group"
: "Systemgruppe"

, "Group"
: "Gruppe"

, "List Information"
: "Gruppeninformationen"

, "{0} must be given"
: "{0} muss gegeben sein"

, "Company address"
: "Firmenadresse"

, "Private address"
: "Privatadresse"

, "Select contact"
: "Kontakt auswählen"

, "Private"
: "Privat"

, "Info"
: "Info"

, "Insecure link"
: "Unsicherer Link"

, "Please review this link in edit dialog."
: "Bitte überprüfen Sie den Link im Detail-Dialog."

, "Export {0}, Export {0}"
: [
  "{0} exportieren"
 ,"{0} exportieren"

]
, "Export as PDF"
: "Als PDF exportieren"

, "Export as CSV"
: "Als CSV exportieren"

, "Export as ODS"
: "Als ODS exportieren"

, "Export as XLS"
: "Als XLS exportieren"

, "Export as DOC"
: "Exportieren als DOC"

, "Export as ..."
: "Exportieren als ..."

, "Import contacts"
: "Kontakte importieren"

, "Contact of a user account"
: "Kontakt eines Nutzerkontos"

, "No name"
: "Kein Name"

, "Full Name"
: "Vollständiger Name"

, "Postalcode"
: "Postleitzahl"

, "Street (private)"
: "Straße (privat)"

, "City (private)"
: "Stadt (privat)"

, "Region (private)"
: "Region (privat)"

, "Postalcode (private)"
: "Postleitzahl (privat)"

, "Country (private)"
: "Land (privat)"

, "Car phone"
: "Auto-Telefon"

, "Pager"
: "Pager"

, "Email (private)"
: "E-Mail (privat)"

, "URL (private)"
: "Webseite (privat)"

, "Note"
: "Notizen"

, "Timezone"
: "Zeitzone"

, "Geo"
: "Geografischer Ort"

, "Search for users ..."
: "Suche nach Benutzern ..."

, "Search for Contacts ..."
: "Suche nach Kontakten ..."

, "Uploaded new contact image."
: "Ein neues Kontaktbild wurde hochgeladen."

, "All contacts"
: "Alle Kontakte"

, "Default Addressbook"
: "Standard Adressbuch"

, "The default addressbook for new contacts"
: "Standard-Adressbuch für neue Kontakte"

, "Default Favorite"
: "Standard Favorit"

, "The default favorite which is loaded on addressbook startup"
: "Der Standard Favorit der beim öffnen des Adressbuches geladen wird"

, "Contacts ODS export configuration"
: "Kontakt ODS-Export Konfiguration"

, "Use this configuration for the contact ODS export."
: "Hiermit können Sie die zu verwendende Kontakt ODS-Export Konfiguration einstellen."

, "Contacts XLS export configuration"
: "Kontakt XLS-Export Konfiguration"

, "Use this configuration for the contact XLS export."
: "Hiermit können Sie die zu verwendende XLS-Export Konfiguration einstellen."

, "default"
: "Standard"

, "This contact has been automatically added by the system as an event attender"
: "Dieser Kontakt wurde automatisch vom System als Termin Teilnehmer hinzugefügt."

, "All Contacts"
: "Alle Kontakte"

, "Enabled Features"
: "Feature aktivieren"

, "Enabled Features in Calendar Application."
: "Feature in der Kalender Applikation aktivieren."

, "Addressbook List View"
: "Adressbuch Listenansicht"

, "Shows an additional view for lists inside the addressbook)"
: ""

, "Contact duplicate check fields"
: "Kontaktfelder für den Dublettencheck"

, "These fields are checked when a new contact is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: "Diese Felder werden überprüft, wenn ein neuer Kontakt erstellt wird. Falls ein Eintrag mit den gleichen Daten in diesen Feldern angelegt wird, wird eine Fehlermeldung angezeit, auf die der Benutzer reagieren kann."

, "Contact salutations available"
: "Verfügbare Kontaktanreden"

, "Possible contact salutations. Please note that additional values might impact other Addressbook systems on export or syncronisation."
: "Mögliche Kontaktanreden. Bitte beachten Sie, dass sich zusätzliche Werte beim Export oder der Synchronisation auf andere Systeme auswirken."

, "Mr"
: "Herr"

, "Ms"
: "Frau"

, "Parsing rules for addresses"
: "Analyseregeln für Adressen"

, "Path to a XML file with address parsing rules."
: "Pfad zu einer XML-Datei mit den Analyseregeln für Adressen."

, "List types available"
: "Verfügbare Listen Typen"

, "List types available."
: "Verfügbare Listen Typen."

, "Department"
: "Abteilung"

, "Mailing list"
: "Mailingliste"

, "Import CSV formated contacts from Outlook 2007 German address book"
: "Importiere CSV formatierte Kontakte aus einem Outlook 2007 Deutsch Adressbuch"

, "CSV Outlook 2007 German"
: "CSV Outlook 2007 Deutsch"

, "LX-Office CSV Contact import"
: "LX-Office CSV Kontakt Import"

, "Import CSV formated contacts from LX-Office"
: "Importiere CSV formatierte Kontakte von LX-Office"

, "Tine 2.0 contact CSV import"
: "Tine 2.0 Kontakt CSV Import"

, "Import CSV formated contacts from Tine 2.0 address book"
: "Importiere CSV formatierte Kontakte aus einem Tine 2.0 Adressbuch"

, "Import list (###CURRENTDATE###)"
: "Importliste (###CURRENTDATE###)"

, "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: "Kontakte importiert am ###CURRENTDATE### um ###CURRENTTIME### von ###USERFULLNAME###"

, "Import CSV formated contacts from Exchange / Outlook address book"
: "Importiere CSV formatierte Kontakte aus einem Exchange / Outlook Adressbuch"

, "Contact CSV import from Outlook address book"
: "CSV-Kontaktimport aus dem Outlook-Adressbuch"

, "Import CSV formated contacts from Google address book"
: "Importiere CSV formatierte Kontakte aus einem Google Adressbuch"

, "Contact import from Google address book"
: "Kontaktimport aus dem Google-Adressbuch"

, "Contact CSV import from mac address book"
: "CSV-Kontaktimport aus dem Mac-Adressbuch"

, "Import vCard formated contacts"
: "Importiere vCard formatierte Kontakte"

, "Contact VCARD import"
: "VCARD-Import für Kontakte"

, "Internal Contacts"
: "Interne Kontakte"

, "All contacts I have read grants for"
: "Alle Kontakte für die ich Lese-Rechte habe"

, "My company"
: "Meine Firma"

, "All coworkers in my company"
: "Alle Mitarbeiter meiner Firma"

, "My contacts"
: "Meine Kontakte"

, "All contacts in my Addressbooks"
: "Alle Kontakte in meinen Adressbüchern"

, "Last modified by me"
: "Zuletzt von mir bearbeitet"

, "All contacts that I have last modified"
: "Alle Kontakte, die ich zuletzt bearbeitet habe"

, "Contact"
: "Kontakt"

, "List Role"
: "Gruppenrolle"

, "Addressbook"
: "Adressbuch"

, "List"
: "Gruppe"

, "Email Address"
: "E-mail Adresse"

, "Export {0}"
: "{0} exportieren"

}));

==> tine20-allinone_2017.08.11.tar.bz2: Addressbook/js/Addressbook-lang-de-debug.js <==
/********************** tine translations of Addressbook**********************/ 
Locale.Gettext.prototype._msgs['./LC_MESSAGES/Addressbook'] = new Locale.Gettext.PO(({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-12-04 12:08+0100\nLast-Translator: Cornelius Weiß <c.weiss@metaways.de>\nLanguage-Team: German (http://www.transifex.com/tine20/tine20/language/de/)\nLanguage: de\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-SourceCharset: utf-8\nX-Generator: Poedit 1.8.7.1\n"

, "manage shared addressbooks"
: "Gemeinsame Adressbücher verwalten"

, "Create new shared addressbook folders"
: "Neue gemeinsame Adressbücher anlegen"

, "manage shared addressbook favorites"
: "Gemeinsame Adressbuch-Favoriten verwalten"

, "Create or update shared addressbook favorites"
: "Gemeinsame Adressbuch-Favoriten erstellen oder bearbeiten"

, "Manage lists in CoreData"
: "Verwalte Listen in den Stammdaten"

, "View, create, delete or update lists in CoreData application"
: "Gruppen in den Stammdaten sehen, anlegen, löschen oder bearbeiten"

, "Manage list functions in CoreData"
: "Verwalte Gruppenfunktionen in den Stammdaten"

, "View, create, delete or update list functions in CoreData application"
: "Gruppenfunktionen in den Stammdaten ansehen, anlegen, löschen oder bearbeiten"

, "Enabled Features"
: "Feature aktivieren"

, "Enabled Features in Calendar Application."
: "Feature in der Kalender Applikation aktivieren."

, "Addressbook List View"
: "Adressbuch Listenansicht"

, "Shows an additional view for lists inside the addressbook"
: "Zeigt eine zusätzliche Ansicht für Gruppen im Adressbuch"

, "Addressbook Industries"
: "Adressbuch Branchen"

, "Add Industry field to Adressbook"
: "Fügte das Feld Branchen zum Adressbuch hinzu"

, "Manage resources in Addressbook"
: "Ressourcen im Adressbuch verwalten"

, "Show the resources grid also inside the Addressbook"
: "Die Ressourcen Liste auch im Adressbuch anzeigen"

, "Show Structure Panel in Addressbook"
: "Strukturen Modul im Adressbuch anzeigen "

, "Visualize relations of records"
: "Visualisierung von Beziehungen von Einträgen"

, "Contact duplicate check fields"
: "Kontaktfelder für den Dublettencheck"

, "These fields are checked when a new contact is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: "Diese Felder werden überprüft, wenn ein neuer Kontakt erstellt wird. Falls ein Eintrag mit den gleichen Daten in diesen Feldern angelegt wird, wird eine Fehlermeldung angezeit, auf die der Benutzer reagieren kann."

, "Contact Hidden Criteria"
: "Kriterium zum ausblenden von Kontakten"

, "The contact is hidden if it is ... (one of: disabled, expired or never)"
: "Der Kontakt wird ausgeblendet wenn er ... ist. (eines von: deaktiviert, abgelaufen oder niemals)"

, "Contact salutations available"
: "Verfügbare Kontaktanreden"

, "Possible contact salutations. Please note that additional values might impact other Addressbook systems on export or syncronisation."
: "Mögliche Kontaktanreden. Bitte beachten Sie, dass sich zusätzliche Werte beim Export oder der Synchronisation auf andere Systeme auswirken."

, "Mr"
: "Herr"

, "Ms"
: "Frau"

, "Company"
: "Firma"

, "Parsing rules for addresses"
: "Analyseregeln für Adressen"

, "Path to a XML file with address parsing rules."
: "Pfad zu einer XML-Datei mit den Analyseregeln für Adressen."

, "List types available"
: "Verfügbare Listen Typen"

, "List types available."
: "Verfügbare Listen Typen."

, "Department"
: "Abteilung"

, "Mailing list"
: "Mailingliste"

, "Use Nominatim during contact import"
: "Nutzung der Nominatim API während des Kontakt Imports"

, "Sync Backends"
: "Synchronisations Backends"

, "Uploaded new contact image."
: "Ein neues Kontaktbild wurde hochgeladen."

, "Deleted contact image."
: "Lösche Kontaktbild"

, "%s's personal addressbook"
: "%ss persönliches Adressbuch"

, "Lists"
: "Gruppen"

, "List Functions"
: "Gruppenfunktionen"

, "Industries"
: "Branchen"

, "Excel phone list"
: "Excel - Telefonliste"

, "Excel phone list grouped by company"
: "Excel - Telefonliste, gruppiert nach Firma"

, "CSV all data"
: "CSV - Alle Daten"

, "OpenDocument all data"
: "OpenDocument - Alle Daten"

, "Word details"
: "Word - Details"

, "Word letter"
: "Word - Brief"

, "Excel overview"
: "Excel - Übersicht"

, "Excel all data"
: "Excel - Alle Daten"

, "PDF details"
: "PDF - Details"

, "Business Contact Data"
: "Geschäftliche Kontaktdaten"

, "Organisation / Unit"
: "Firma / Abteilung"

, "Business Address"
: "Geschäftliche Anschrift"

, "Email"
: "E-Mail"

, "Telephone Work"
: "Telefon (Büro)"

, "Telephone Cellphone"
: "Telefon (Mobil)"

, "Telephone Car"
: "Telefon (Auto)"

, "Telephone Fax"
: "Fax"

, "Telephone Page"
: "Pager"

, "URL"
: "URL"

, "Role"
: "Funktion"

, "Room"
: "Raum"

, "Assistant"
: "Assistent"

, "Assistant Telephone"
: "Telefon des Assistenten"

, "Private Contact Data"
: "Private Kontaktdaten"

, "Private Address"
: "Private Anschrift"

, "Email Home"
: "E-Mail  (Zuhause)"

, "Telephone Home"
: "Telefon  (Zuhause)"

, "Telephone Cellphone Private"
: "Telefon (Mobil)"

, "Telephone Fax Home"
: "Fax (Zuhause)"

, "URL Home"
: "URL (Zuhause)"

, "Other Data"
: "Andere Daten"

, "Birthday"
: "Geburtstag"

, "Job Title"
: "Berufs-Bezeichnung"

, "All Contacts"
: "Alle Kontakte"

, "This contact has been automatically added by the system as an event attender"
: "Dieser Kontakt wurde automatisch vom System als Termin Teilnehmer hinzugefügt."

, "Import CSV formated contacts from Google address book"
: "Importiere CSV formatierte Kontakte aus einem Google Adressbuch"

, "Contact import from Google address book"
: "Kontaktimport aus dem Google-Adressbuch"

, "Import vCard formated contacts"
: "Importiere vCard formatierte Kontakte"

, "Contact VCARD import"
: "VCARD-Import für Kontakte"

, "LX-Office CSV Contact import"
: "LX-Office CSV Kontakt Import"

, "Import CSV formated contacts from LX-Office"
: "Importiere CSV formatierte Kontakte von LX-Office"

, "Contact CSV import from mac address book"
: "CSV-Kontaktimport aus dem Mac-Adressbuch"

, "Import CSV formated contacts from Outlook 2007 German address book"
: "Importiere CSV formatierte Kontakte aus einem Outlook 2007 Deutsch Adressbuch"

, "CSV Outlook 2007 German"
: "CSV Outlook 2007 Deutsch"

, "Import CSV formated contacts from Exchange / Outlook address book"
: "Importiere CSV formatierte Kontakte aus einem Exchange / Outlook Adressbuch"

, "Contact CSV import from Outlook address book"
: "CSV-Kontaktimport aus dem Outlook-Adressbuch"

, "Tine 2.0 contact CSV import"
: "Tine 2.0 Kontakt CSV Import"

, "Import CSV formated contacts from Tine 2.0 address book"
: "Importiere CSV formatierte Kontakte aus einem Tine 2.0 Adressbuch"

, "Import list (###CURRENTDATE###)"
: "Importliste (###CURRENTDATE###)"

, "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: "Kontakte importiert am ###CURRENTDATE### um ###CURRENTTIME### von ###USERFULLNAME###"

, "New Contact"
: "Neuer Kontakt"

, "Addressbook, Addressbooks"
: [
  "Adressbuch"
 ,"Adressbücher"

]
, "ID"
: "ID"

, "Name"
: "Name"

, "Description"
: "Beschreibung"

, "Structure, Structures"
: [
  "Struktur"
 ,"Strukturen"

]
, "Resources"
: "Ressourcen"

, "CardDAV URL"
: "CardDAV URL"

, "Map"
: "Karte"

, "Preferred Address"
: "Bevorzugte Adresse"

, "Personal Information"
: "Persönliche Informationen"

, "Salutation"
: "Anrede"

, "Title"
: "Titel"

, "First Name"
: "Vorname"

, "Middle Name"
: "zweiter Vorname"

, "Last Name"
: "Nachname"

, "Unit"
: "Abteilung"

, "Suffix"
: "Namenszusatz"

, "Job Role"
: "Funktion"

, "Display Name"
: "Angezeigter Name"

, "Industry, Industries"
: [
  "Branche"
 ,"Branchen"

]
, "Contact Information"
: "Kontakt-Informationen"

, "Phone"
: "Telefon"

, "Mobile"
: "Handy"

, "Fax"
: "Fax"

, "Phone (private)"
: "Telefon (privat)"

, "Mobile (private)"
: "Handy (privat)"

, "Fax (private)"
: "Fax (privat)"

, "E-Mail"
: "E-Mail"

, "E-Mail (private)"
: "E-Mail (privat)"

, "Web"
: "Internet"

, "Company Address"
: "Geschäftliche Anschrift"

, "Street"
: "Straße"

, "Street 2"
: "Straße 2"

, "Region"
: "Region"

, "Postal Code"
: "Postleitzahl"

, "City"
: "Ort"

, "Country"
: "Land"

, "Enter description"
: "Bitte geben Sie eine Beschreibung an"

, "Groups"
: "Gruppen"

, "Parse address"
: "Adresse einlesen"

, "Print contact"
: "Kontakt drucken"

, "Paste address"
: "Adresse einfügen"

, "Please paste an address or a URI to a vcard that should be parsed:"
: "Bitte fügen Sie eine Adresse oder URI zu einer vcard ein, die eingelesen werden soll:"

, "Failed to parse address!"
: "Einlesen der Adresse fehlgeschlagen!"

, "The address could not be read."
: "Die Adresse konnte nicht gelesen werden."

, "End token mode"
: "Beende Merkmalsmodus"

, "Contact, Contacts"
: [
  "Kontakt"
 ,"Kontakte"

]
, "Import contacts"
: "Kontakte importieren"

, "Contact of a user account"
: "Kontakt eines Nutzerkontos"

, "No name"
: "Kein Name"

, "Business"
: "Geschäft"

, "Private"
: "Privat"

, "Not set"
: "Nicht gesetzt"

, "Type"
: "Typ"

, "Tags"
: "Tags"

, "Full Name"
: "Vollständiger Name"

, "Postalcode"
: "Postleitzahl"

, "Street (private)"
: "Straße (privat)"

, "City (private)"
: "Stadt (privat)"

, "Region (private)"
: "Region (privat)"

, "Postalcode (private)"
: "Postleitzahl (privat)"

, "Country (private)"
: "Land (privat)"

, "Car phone"
: "Auto-Telefon"

, "Pager"
: "Pager"

, "Email (private)"
: "E-Mail (privat)"

, "URL (private)"
: "Webseite (privat)"

, "Note"
: "Notizen"

, "Timezone"
: "Zeitzone"

, "Geo"
: "Geografischer Ort"

, "Search for users ..."
: "Suche nach Benutzern ..."

, "Search for Contacts ..."
: "Suche nach Kontakten ..."

, "Print {0}"
: "{0} Drucken"

, "List Information"
: "Gruppeninformationen"

, "List type"
: "Listen Typ"

, "{0} must be given"
: "{0} muss gegeben sein"

, "Emails"
: "E-Mail"

, "System Group"
: "Systemgruppe"

, "Group"
: "Gruppe"

, "Select list"
: "Gruppe auswählen"

, "List, Lists"
: [
  "Gruppe"
 ,"Gruppen"

]
, "Member of List"
: "Gruppenmitglied"

, "Members"
: "Mitglieder"

, "Remove Member"
: "Mitglied entfernen"

, "List Function, List Functions"
: [
  "Gruppenfunktion"
 ,"Gruppenfunktionen"

]
, "Search for system groups ..."
: "Suche nach Systemgruppen ..."

, "Search for groups ..."
: "Suche nach Gruppen ..."

, "Company address"
: "Firmenadresse"

, "Private address"
: "Privatadresse"

, "Street (Company Address)"
: "Straße (Geschäftliche Anschrift)"

, "Street 2 (Company Address)"
: "Straße 2 (Geschäftliche Anschrift)"

, "City (Company Address)"
: "Ort (Geschäftliche Anschrift)"

, "Region (Company Address)"
: "Region (Geschäftliche Anschrift)"

, "Postal Code (Company Address)"
: "Postleitzahl (Geschäftliche Anschrift)"

, "Country (Company Address)"
: "Land (Geschäftliche Anschrift)"

, "Longitude (Company Address)"
: "Längengrad (Firmenadresse )"

, "Latitude (Company Address)"
: "Breitengrad (Firmenadresse )"

, "Street (Private Address)"
: "Straße (Private Anschrift)"

, "Street 2 (Private Address)"
: "Straße 2 (Private Anschrift)"

, "City (Private Address)"
: "Ort (Private Anschrift)"

, "Region (Private Address)"
: "Region (Private Anschrift)"

, "Postal Code (Private Address)"
: "Postleitzahl (Private Anschrift)"

, "Country (Private Address)"
: "Land (Private Anschrift)"

, "Company Communication"
: "Firmenkommunikation"

, "Private Communication"
: "Privatkommunikation"

, "Web (private)"
: "Webseite (Privat)"

, "Contacts"
: "Kontakte"

, "Addressbooks"
: "Adressbücher"

, "User Account"
: "Benutzerkonto"

, "Quick Search"
: "Schnellsuche"

, "Last Modified Time"
: "Zuletzt geändert"

, "Last Modified By"
: "Zuletzt geändert von"

, "Creation Time"
: "Erstelldatum"

, "Created By"
: "Angelegt von"

, "Quick search"
: "Schnellsuche"

, "Email Address, Email Addresses"
: [
  "E-mail Adresse"
 ,"E-mail Adressen"

]
, "Email Addresses"
: "E-mail Adressen"

, "Structures"
: "Strukturen"

, "Related to"
: "Verknüpft mit"

, "Customfields"
: "Zusatzfelder"

, "Select record to see its details"
: "Eintrag auswählen um Details zu sehen"

, "This module visualises hierarchically depended relations between records of different types."
: "Dieses Modul visualisiert hierarchisch abhängige Beziehungen zwischen Einträgen verschiedener Typen. "

, "Hierarchically depended relations are created automatically for some data types like users and groups, but can also be created manually via the corresponding relation types."
: "Hierarchisch abhängige Beziehungen werden von einigen Datentypen wie z.B. Benutzern und Gruppen automatisch  erstellt. Sie können aber auch manuell mit den entsprechenden Verknüpfungstypen erzeugt werden."

, "Loading Structure data..."
: "Lade Strukturdaten..."

, "Percent"
: "Prozent"

, "All contacts"
: "Alle Kontakte"

, "Default Addressbook"
: "Standard Adressbuch"

, "The default addressbook for new contacts"
: "Standard-Adressbuch für neue Kontakte"

, "Default Favorite"
: "Standard Favorit"

, "The default favorite which is loaded on addressbook startup"
: "Der Standard Favorit der beim öffnen des Adressbuches geladen wird"

, "Contacts ODS export configuration"
: "Kontakt ODS-Export Konfiguration"

, "Use this configuration for the contact ODS export."
: "Hiermit können Sie die zu verwendende Kontakt ODS-Export Konfiguration einstellen."

, "Contacts XLS export configuration"
: "Kontakt XLS-Export Konfiguration"

, "Use this configuration for the contact XLS export."
: "Hiermit können Sie die zu verwendende XLS-Export Konfiguration einstellen."

, "default"
: "Standard"

, "All contacts I have read grants for"
: "Alle Kontakte für die ich Lese-Rechte habe"

, "My company"
: "Meine Firma"

, "All coworkers in my company"
: "Alle Mitarbeiter meiner Firma"

, "My contacts"
: "Meine Kontakte"

, "All contacts in my Addressbooks"
: "Alle Kontakte in meinen Adressbüchern"

, "Last modified by me"
: "Zuletzt von mir bearbeitet"

, "All contacts that I have last modified"
: "Alle Kontakte, die ich zuletzt bearbeitet habe"

, "Internal Contacts"
: "Interne Kontakte"






















, "Addressbook"
: "Adressbuch"

, "Structure"
: "Struktur"

, "Industry"
: "Branche"

, "Contact"
: "Kontakt"

, "List"
: "Gruppe"

, "List Function"
: "Gruppenfunktion"

, "Email Address"
: "E-mail Adresse"

}));
